@@ -96,7 +96,7 @@ def SequenceHomogeneity(pValueList:list,posList:list,pValueAccepted:float,organi
         
         
         #Creating the figure
-        fig=plt.figure(figsize=(100,10))#figsize=(blueRectangleLength*2,blueRectangleHeight*2))
+        fig=plt.figure()#figsize=(blueRectangleLength*2,blueRectangleHeight*2))
         ax=fig.add_subplot(111)
         
         #Annotations
